LOG_COMMON_CORE = 'common.core'
LOG_COMMON_CORE_WEB_INTERCEPTOR = 'common.core.web.interceptor'

LOG_COMMON_CORE_ODBC_CONNECTION = 'common.core.odbc.connection'
LOG_COMMON_CORE_ODBC_QUERY = 'app.core.odbc.query'

LOG_COMMON_CORE_CLOUD_BIGQUERY = 'app.core.cloud.bigquery'

LOG_COMMON_CORE_MQTT = 'common.core.mqtt'
LOG_COMMON_CORE_FETCHER = 'common.core.fetcher'
LOG_COMMON_CORE_GPIO = 'common.core.gpio'
LOG_COMMON_CORE_PLATFORM = 'common.core.platform'

LOG_APP_TREND = 'app.trend'
LOG_APP_ASSET = 'app.asset'
